Module android

Module android 

Structs

Key
Key for signing APK.

Functions

add_libs_into_apk
Adds given lib and all reletad libs into APK. Uses readelf, aapt tools.
align_apk
Aligns APK on 4-byte memory boundary. Uses zipalign build tools.
attach_logger_only_rust
Attach logger to device with filter that passes only Rust Stdout or Stderr. Runsadb logcat RustStdoutStderr:D '*:S' command.
compile_rust_for_android
Compiles rust code for android.
detect_abi
Returns current android target. Runs adb shell getprop ro.product.cpu.abi command.
gen_debug_key
Generates debug key for signing APK. Runs keytool ... command.
gen_minimal_android_manifest
Generates minimal AndroidManifest with given changes.
gen_unaligned_apk
Generates unaligned APK with given manifest_path, assets and res. Uses aapt build tool.
install_apk
Installs given APK in emulator or connected device. Runs adb install -r ... command.
read_android_manifest
Read file and deserializes AndroidManifest.xml into AndroidManifest.
save_android_manifest
Saves given manifest in new AndroidManifest.xml file.
sign_apk
Signs APK with given key. Uses apksigner build tool.
start_apk
Starts installed APK on on emulator or connected device. Runs adb shell am start ... command.