Aapt2Dump

Struct Aapt2Dump 

pub struct Aapt2Dump { /* private fields */ }
Dump

Dump is used for printing information about the APK you generated using the link command. For example, the following command prints content from the resource table of the specified APK:

aapt2 dump resources output.apk

Dump syntax

The general syntax for using dump is as follows:

aapt2 dump sub-command filename.apk [options]

Implementations

Source

impl Aapt2Dump

pub fn new(subcommand: SubCommand, filename_apk: &Path) -> Aapt2Dump

pub fn no_values(&mut self, no_values: bool) -> &mut Self

pub fn file(&mut self, file: &Path) -> &mut Self

pub fn v(&mut self, v: bool) -> &mut Self

pub fn run(&self)