Structs
- Key
- Key for signing APK.
Functions
- add_
libs_ into_ apk - Adds given lib and all reletad libs into APK.
Uses
readelf,aapttools. - align_
apk - Aligns APK on 4-byte memory boundary.
Uses
zipalignbuild tools. - attach_
logger_ only_ rust - Attach logger to device with filter that passes only Rust Stdout or Stderr.
Runs
adb logcat RustStdoutStderr:D '*:S'command. - compile_
rust_ for_ android - Compiles rust code for android.
- detect_
abi - Returns current android target.
Runs
adb shell getprop ro.product.cpu.abicommand. - gen_
debug_ key - Generates debug key for signing APK.
Runs
keytool ...command. - gen_
minimal_ android_ manifest - Generates minimal
AndroidManifestwith given changes. - gen_
unaligned_ apk - Generates unaligned APK with given
manifest_path,assetsandres. Usesaaptbuild tool. - install_
apk - Installs given APK in emulator or connected device.
Runs
adb install -r ...command. - read_
android_ manifest - Read file and deserializes
AndroidManifest.xmlintoAndroidManifest. - save_
android_ manifest - Saves given manifest in new
AndroidManifest.xmlfile. - sign_
apk - Signs APK with given key.
Uses
apksignerbuild tool. - start_
apk - Starts installed APK on on emulator or connected device.
Runs
adb shell am start ...command.