Structs
- Config
- Configuration information for creator. This is not specific to a build, it is information relating to creator itself.
- Shell
- An abstraction around console output that remembers preferences for output verbosity and color.
Enums
- Color
Choice - Whether messages should use color output
- TtyWidth
- Verbosity
- The requested verbosity of output.